# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

from tester.api_helper import APIHelper
from tester.configuration import Configuration
from tester.configuration import Server
from tester.controllers.base_controller import BaseController
from tester.models.complex_5 import Complex5
from tester.exceptions.nested_model_exception import NestedModelException
from tester.exceptions.local_test_exception import LocalTestException
from tester.exceptions.unix_time_stamp_exception import UnixTimeStampException
from tester.exceptions.rfc_1123_exception import Rfc1123Exception
from tester.exceptions.exception_with_rfc_3339_date_time_exception import ExceptionWithRfc3339DateTimeException
from tester.exceptions.custom_error_response_exception import CustomErrorResponseException
from tester.exceptions.exception_with_date_exception import ExceptionWithDateException
from tester.exceptions.exception_with_uuid_exception import ExceptionWithUUIDException
from tester.exceptions.exception_with_dynamic_exception import ExceptionWithDynamicException
from tester.exceptions.exception_with_precision_exception import ExceptionWithPrecisionException
from tester.exceptions.exception_with_boolean_exception import ExceptionWithBooleanException
from tester.exceptions.exception_with_long_exception import ExceptionWithLongException
from tester.exceptions.exception_with_number_exception import ExceptionWithNumberException
from tester.exceptions.exception_with_string_exception import ExceptionWithStringException


class ErrorCodesController(BaseController):

    """A Controller to access Endpoints in the tester API."""

    def __init__(self, config, call_back=None):
        super(ErrorCodesController, self).__init__(config, call_back)

    def catch_412_global_error(self):
        """Does a GET request to /error/412.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/412'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def get_501(self):
        """Does a GET request to /error/501.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/501'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 501:
            raise NestedModelException('error 501', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def get_400(self):
        """Does a GET request to /error/400.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/400'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def get_500(self):
        """Does a GET request to /error/500.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/500'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def get_401(self):
        """Does a GET request to /error/401.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/401'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 401:
            raise LocalTestException('401 Local', _response)
        elif _response.status_code == 421:
            raise LocalTestException('Default', _response)
        elif _response.status_code == 431:
            raise LocalTestException('Default', _response)
        elif _response.status_code == 432:
            raise LocalTestException('Default', _response)
        elif _response.status_code == 441:
            raise LocalTestException('Default', _response)
        elif (_response.status_code < 200) or (_response.status_code > 208):
            raise LocalTestException('Invalid response.', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def receive_exception_with_unixtimestamp_exception(self):
        """Does a GET request to /error/unixTimeStampException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/unixTimeStampException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise UnixTimeStampException('unixtimestamp exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def receive_exception_with_rfc_1123_datetime(self):
        """Does a GET request to /error/rfc1123Exception.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/rfc1123Exception'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise Rfc1123Exception('Rfc1123 Exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def receive_exception_with_rfc_3339_datetime(self):
        """Does a GET request to /error/Rfc3339InException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/Rfc3339InException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithRfc3339DateTimeException('DateTime Exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def receive_endpoint_level_exception(self):
        """Does a GET request to /error/451.

        TODO: type endpoint description here.

        Returns:
            Complex5: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/451'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 451:
            raise CustomErrorResponseException('caught endpoint exception', _response)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.raw_body, Complex5.from_dictionary)

        return decoded

    def receive_global_level_exception(self):
        """Does a GET request to /error/450.

        TODO: type endpoint description here.

        Returns:
            Complex5: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/450'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.raw_body, Complex5.from_dictionary)

        return decoded

    def date_in_exception(self):
        """Does a GET request to /error/dateInException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/dateInException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithDateException('date in exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def uuid_in_exception(self):
        """Does a GET request to /error/uuidInException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/uuidInException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithUUIDException('uuid in exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def dynamic_in_exception(self):
        """Does a GET request to /error/dynamicInException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/dynamicInException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithDynamicException('dynamic in Exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def precision_in_exception(self):
        """Does a GET request to /error/precisionInException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/precisionInException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithPrecisionException('precision in Exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def boolean_in_exception(self):
        """Does a GET request to /error/booleanInException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/booleanInException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithBooleanException('Boolean in Exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def long_in_exception(self):
        """Does a GET request to /error/longInException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/longInException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithLongException('long in exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def number_in_exception(self):
        """Does a GET request to /error/numberInException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/numberInException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithNumberException('number in exception', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded

    def get_exception_with_string(self):
        """Does a GET request to /error/stringInException.

        TODO: type endpoint description here.

        Returns:
            mixed: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/error/stringInException'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        elif _response.status_code == 444:
            raise ExceptionWithStringException('exception with string', _response)
        self.validate_response(_response)
        if (_response.raw_body is not None) or (not str(_response.raw_body)):
            decoded = APIHelper.json_deserialize(_response.raw_body)

        return decoded



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

from tester.api_helper import APIHelper
from tester.configuration import Configuration
from tester.configuration import Server
from tester.controllers.base_controller import BaseController
from tester.models.echo_response import EchoResponse


class TemplateParamsController(BaseController):

    """A Controller to access Endpoints in the tester API."""

    def __init__(self, config, call_back=None):
        super(TemplateParamsController, self).__init__(config, call_back)

    def send_string_array(self,
                          strings):
        """Does a GET request to /{strings}.

        TODO: type endpoint description here.

        Args:
            strings (list of string): TODO: type description here.

        Returns:
            EchoResponse: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Validate required parameters
        self.validate_parameters(strings=strings)

        # Prepare query URL
        _url_path = '/{strings}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'strings': strings
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.raw_body, EchoResponse.from_dictionary)

        return decoded

    def send_integer_array(self,
                           integers):
        """Does a GET request to /{integers}.

        TODO: type endpoint description here.

        Args:
            integers (list of int): TODO: type description here.

        Returns:
            EchoResponse: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Validate required parameters
        self.validate_parameters(integers=integers)

        # Prepare query URL
        _url_path = '/{integers}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'integers': integers
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.raw_body, EchoResponse.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""
import tester.models.redirect_settings
import tester.models.signature_type
import tester.models.ui


class Signer(object):

    """Implementation of the 'Signer' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        url (string): TODO: type description here.
        links (list of string): TODO: type description here.
        external_signer_id (string): TODO: type description here.
        redirect_settings (RedirectSettings): TODO: type description here.
        signature_type (SignatureType): TODO: type description here.
        ui (Ui): TODO: type description here.
        tags (list of string): TODO: type description here.
        order (int): TODO: type description here.
        required (bool): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "external_signer_id": 'externalSignerId',
        "id": 'id',
        "links": 'links',
        "order": 'order',
        "redirect_settings": 'redirectSettings',
        "required": 'required',
        "signature_type": 'signatureType',
        "tags": 'tags',
        "ui": 'ui',
        "url": 'url'
    }

    def __init__(self,
                 external_signer_id=None,
                 id=None,
                 links=None,
                 order=None,
                 redirect_settings=None,
                 required=None,
                 signature_type=None,
                 tags=None,
                 ui=None,
                 url=None,
                 additional_properties={}):
        """Constructor for the Signer class"""

        # Initialize members of the class
        self.id = id
        self.url = url
        self.links = links
        self.external_signer_id = external_signer_id
        self.redirect_settings = redirect_settings
        self.signature_type = signature_type
        self.ui = ui
        self.tags = tags
        self.order = order
        self.required = required

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        external_signer_id = dictionary.get('externalSignerId')
        id = dictionary.get('id')
        links = dictionary.get('links')
        order = dictionary.get('order')
        redirect_settings = tester.models.redirect_settings.RedirectSettings.from_dictionary(dictionary.get('redirectSettings')) if dictionary.get('redirectSettings') else None
        required = dictionary.get('required')
        signature_type = tester.models.signature_type.SignatureType.from_dictionary(dictionary.get('signatureType')) if dictionary.get('signatureType') else None
        tags = dictionary.get('tags')
        ui = tester.models.ui.Ui.from_dictionary(dictionary.get('ui')) if dictionary.get('ui') else None
        url = dictionary.get('url')

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(external_signer_id,
                   id,
                   links,
                   order,
                   redirect_settings,
                   required,
                   signature_type,
                   tags,
                   ui,
                   url,
                   dictionary)



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from tester.api_helper import APIHelper
from tester.controllers.error_codes_controller import ErrorCodesController
from tester.exceptions.nested_model_exception import NestedModelException
from tester.exceptions.global_test_exception import GlobalTestException
from tester.exceptions.local_test_exception import LocalTestException
from tester.exceptions.unix_time_stamp_exception import UnixTimeStampException
from tester.exceptions.rfc_1123_exception import Rfc1123Exception
from tester.exceptions.exception_with_rfc_3339_date_time_exception import ExceptionWithRfc3339DateTimeException
from tester.exceptions.custom_error_response_exception import CustomErrorResponseException
from tester.exceptions.exception_with_date_exception import ExceptionWithDateException
from tester.exceptions.exception_with_uuid_exception import ExceptionWithUUIDException
from tester.exceptions.exception_with_dynamic_exception import ExceptionWithDynamicException
from tester.exceptions.exception_with_precision_exception import ExceptionWithPrecisionException
from tester.exceptions.exception_with_boolean_exception import ExceptionWithBooleanException
from tester.exceptions.exception_with_long_exception import ExceptionWithLongException
from tester.exceptions.exception_with_number_exception import ExceptionWithNumberException
from tester.exceptions.exception_with_string_exception import ExceptionWithStringException


class ErrorCodesControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(ErrorCodesControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = ErrorCodesController(cls.config, cls.response_catcher)

    def test_check_controller_type(self):
        self.assertTrue(type(self.client.error_codes) is ErrorCodesController)

    # Todo: Add description for test test_get_412_global_exception
    def test_get_412_global_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(NestedModelException):
            result = self.controller.catch_412_global_error()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 412)

    # Todo: Add description for test test_get_501
    def test_get_501(self):

        # Perform the API call through the SDK function
        with self.assertRaises(NestedModelException):
            result = self.controller.get_501()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 501)

    # Todo: Add description for test test_get_400
    def test_get_400(self):

        # Perform the API call through the SDK function
        with self.assertRaises(GlobalTestException):
            result = self.controller.get_400()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 400)

    # Todo: Add description for test test_get_500
    def test_get_500(self):

        # Perform the API call through the SDK function
        with self.assertRaises(GlobalTestException):
            result = self.controller.get_500()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 500)

    # Todo: Add description for test test_receive_unix_timestamp_exception
    def test_receive_unix_timestamp_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(UnixTimeStampException):
            result = self.controller.receive_exception_with_unixtimestamp_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_receive_rfc_1123_exception
    def test_receive_rfc_1123_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(Rfc1123Exception):
            result = self.controller.receive_exception_with_rfc_1123_datetime()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_test_rfc_3339_date_time_exception
    def test_test_rfc_3339_date_time_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithRfc3339DateTimeException):
            result = self.controller.receive_exception_with_rfc_3339_datetime()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_check_endpoint_level_exception
    def test_check_endpoint_level_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(CustomErrorResponseException):
            result = self.controller.receive_endpoint_level_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 451)

    # Todo: Add description for test test_check_global_level_exception
    def test_check_global_level_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(CustomErrorResponseException):
            result = self.controller.receive_global_level_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 450)

    # Todo: Add description for test test_date_in_exception
    def test_date_in_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithDateException):
            result = self.controller.date_in_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_uuid_in_exception
    def test_uuid_in_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithUUIDException):
            result = self.controller.uuid_in_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_dynamic_in_exception
    def test_dynamic_in_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithDynamicException):
            result = self.controller.dynamic_in_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_precision_in_exception
    def test_precision_in_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithPrecisionException):
            result = self.controller.precision_in_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_boolean_in_exception
    def test_boolean_in_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithBooleanException):
            result = self.controller.boolean_in_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_long_in_exception
    def test_long_in_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithLongException):
            result = self.controller.long_in_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_number_in_exception
    def test_number_in_exception(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithNumberException):
            result = self.controller.number_in_exception()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)

    # Todo: Add description for test test_exception_with_string
    def test_exception_with_string(self):

        # Perform the API call through the SDK function
        with self.assertRaises(ExceptionWithStringException):
            result = self.controller.get_exception_with_string()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 444)




# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""
import tester.models.dialogs
import tester.models.styling


class Ui(object):

    """Implementation of the 'Ui' model.

    TODO: type model description here.

    Attributes:
        dialogs (Dialogs): TODO: type description here.
        language (LanguageEnum): TODO: type description here.
        styling (Styling): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "dialogs": 'dialogs',
        "language": 'language',
        "styling": 'styling'
    }

    def __init__(self,
                 dialogs=None,
                 language=None,
                 styling=None,
                 additional_properties={}):
        """Constructor for the Ui class"""

        # Initialize members of the class
        self.dialogs = dialogs
        self.language = language
        self.styling = styling

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        dialogs = tester.models.dialogs.Dialogs.from_dictionary(dictionary.get('dialogs')) if dictionary.get('dialogs') else None
        language = dictionary.get('language')
        styling = tester.models.styling.Styling.from_dictionary(dictionary.get('styling')) if dictionary.get('styling') else None

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(dialogs,
                   language,
                   styling,
                   dictionary)



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from tester.api_helper import APIHelper
from tester.controllers.header_controller import HeaderController


class HeaderControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(HeaderControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = HeaderController(cls.config, cls.response_catcher)

    def test_check_controller_type(self):
        self.assertTrue(type(self.client.header) is HeaderController)

    # Todo: Add description for test test_send_headers
    def test_send_headers(self):
        # Parameters for the API call
        custom_header = 'TestString'
        value = 'TestString'

        # Perform the API call through the SDK function
        result = self.controller.send_headers(custom_header, value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))





# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""
import tester.models.before


class Dialogs(object):

    """Implementation of the 'Dialogs' model.

    TODO: type model description here.

    Attributes:
        before (Before): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "before": 'before'
    }

    def __init__(self,
                 before=None,
                 additional_properties={}):
        """Constructor for the Dialogs class"""

        # Initialize members of the class
        self.before = before

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        before = tester.models.before.Before.from_dictionary(dictionary.get('before')) if dictionary.get('before') else None

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(before,
                   dictionary)
